==> ocstore25_6_20.zip: OcStore/Prgm/data/language/en-us/script/CS_seapath.lua <==
function E0090()
    MNA()CMU("XXXX")FAI(0)
end
function E0091()
    MNA()CMU("XXXX")FAI(1)
end
function E0092()
    MNA()CMU("XXXX")FAI(2)
end
function E0093()
    MNA()CMU("XXXX")FAI(3)
end
function E0094()
    MNA()CMU("XXXX")FAI(4)
end

function CannotGoOut()
    PRI()
    MS4("\nCan't leave the big fish behind!")NOD()
end

function CannotEscape()
    PRI()
    TUR()MS4("\nCannot escape!")NOD()
end

function Door_GoSeaCave()
    if(FLJ("InBossFight")) then
        CannotEscape()
    elseif(FLJ("CannotGoOut")) then
        CannotGoOut()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoSeaCave",0,1)FAO(3)TRA("CS_seacave","E0091",36,13)
    end
end

function Door_GoPuuRestaurant()
    if(FLJ("InBossFight")) then
        CannotEscape()
    elseif(FLJ("CannotGoOut")) then
        CannotGoOut()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoPuuRestaurant",0,1)FAO(1)TRA("CS_puu_restaurant","E0093",4,12)
    end
end


function SomeWhereTalking()
    PRI()
    POS(true)
    DNP("SomeWhereTalking")FLP("SomeWhereTalking")
    MS4("\nYou thought you heard something for a moment...")NOD()CLO()
    FAO(2)TRA("CS_puu_restaurant","SomeWhereTalking",4,12)
end

--龙鱼醒了
function ArowanaWake()
    KEY()
    CNP("Kanpa1","CS_mychar_kanpa_animate",0,0)
    CNP("Arowana1","CS_arowana_animate",0,0)
    ANP("Arowana1","fallen",0)
    --间八开始推动
    ANP("Kanpa1","start_push",0)
    HMC()
    FAI(1)
    WAI(192)
    --鱼醒了
    ANP("Arowana1","wake",0)
    WAI(32)
    MS3("Ouch! Stop dragging me!")
    CAT("\nMy scales are coming off!")WAI(32)CLO()
    ANP("Kanpa1","start_push",0)
    WAI(32)
    ANP("Kanpa1","end_push",0)
    WAI(32)
    ANP("Arowana1","makeSmoke",1)
    ANP("Arowana1","normal",1)
    ANP("Kanpa1","MYB",0)
    WAI(32)
    MS3("Who are you?!")NOD()
    MS3("\nWhy did you take me out of the pool?")NOD()
    WAI(8)CAT("\n.")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")CLR()
    ANP("Arowana1","jump",1)
    ANP("Arowana1","angry",1)
    ANP("Kanpa1","MYB",0)
    CAT("What?!")NOD()CAT("You want to feed me to a cat?")NOD()
    CAT("\nI'm the one and only")
    CAT("\nprecious Arowana here!")NOD()CLR()
    CAT("How dare you--!")NOD()
    CAT("\nI'll kill you!!")NOD()CLO()
    SKP("QuackBoss")
    ANP("Kanpa1","MYB",0)
    CMU("CS_Gravity")
    WAI(32)
    CNP("ArowanaBoss","CS_boss_arowana",0,1)
    MNP("ArowanaBoss","Arowana1")
    BSL("ArowanaBoss")
    FLP("InBossFight")
    DNP("Arowana1")
    MOV("Kanpa1")
    DNP("Kanpa1")
    SLR(0)
    SMC()
end

function QuackBoss()
    PRI()
    CMU("CS_Gravity")
    CNP("ArowanaBoss","CS_boss_arowana",0,1)
    MNP("ArowanaBoss",18,10,1)
    ANP("ArowanaBoss",0,1)
    BSL("ArowanaBoss")
    FLP("InBossFight")
    MOV(25,10)
    SLR(0)
    SMC()
    FAI(1)
end

function ArowanaBoss()
    PRI()
    FLS("InBossFight")
    CMU("XXXX")
    MS3("I lost...")NOD()CLR()CLO()
    ANP("ArowanaBoss","set_player_type")--改成玩家类型防止掉下去
    KEY()
    WAI(80)
    CMU("CS_Fanfale3")
    MSG("\nDefeated Arowana!")WAI(140)NOD()
    FLP("CannotGoOut")
    FLP("DefeatedArowana")
    SKS("QuackBoss")
    CMU("XXXX")
    --替换实体
    CNP("ArowanaBoss","GetArowana")
end

function GetArowana()
    PRI()
    GIT("Arowana")ITP("Arowana")SOU("CS_038_get_item")
    ANP("GetArowana","hide")
    DNP("GetArowana")
    CMU("CS_Fanfale1")
    MSG("\nGot the =AROWANA=.")WAI(160)NOD()
    CMU("XXXX")
    FLS("CannotGoOut")
    SetSavePoint()
end

function LoadPos()
    PRI()MNA()CMU("XXXX")
    POS()
    FAI(2)
end

function SetSavePoint()
    CNP("SavePoint","CS_savepoint",0,0)
end

==> ocstore25_8_11.zip: OcStore/Prgm/data/language/en-us/script/CS_seapath.lua <==
function E0090()
    MNA()CMU("XXXX")FAI(0)
end
function E0091()
    MNA()CMU("XXXX")FAI(1)
end
function E0092()
    MNA()CMU("XXXX")FAI(2)
end
function E0093()
    MNA()CMU("XXXX")FAI(3)
end
function E0094()
    MNA()CMU("XXXX")FAI(4)
end

function CannotGoOut()
    PRI()
    MS4("\nCan't leave the big fish behind!")NOD()
end

function CannotEscape()
    PRI()
    TUR()MS4("\nCannot escape!")NOD()
end

function Door_GoSeaCave()
    if(FLJ("InBossFight")) then
        CannotEscape()
    elseif(FLJ("CannotGoOut")) then
        CannotGoOut()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoSeaCave",0,1)FAO(3)TRA("CS_seacave","E0091",36,13)
    end
end

function Door_GoPuuRestaurant()
    if(FLJ("InBossFight")) then
        CannotEscape()
    elseif(FLJ("CannotGoOut")) then
        CannotGoOut()
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoPuuRestaurant",0,1)FAO(1)TRA("CS_puu_restaurant","E0093",4,12)
    end
end


function SomeWhereTalking()
    PRI()
    POS(true)
    DNP("SomeWhereTalking")FLP("SomeWhereTalking")
    MS4("You thought you heard something") 
    CAT("\nfor a moment...")NOD()CLO()
    FAO(2)TRA("CS_puu_restaurant","SomeWhereTalking",4,12)
end

--龙鱼醒了
function ArowanaWake()
    KEY()
    CNP("Kanpa1","CS_mychar_kanpa_animate",0,0)
    CNP("Arowana1","CS_arowana_animate",0,0)
    ANP("Arowana1","fallen",0)
    --间八开始推动
    ANP("Kanpa1","start_push",0)
    HMC()
    FAI(1)
    WAI(192)
    --鱼醒了
    ANP("Arowana1","wake",0)
    WAI(32)
    MS3("Ouch! Stop dragging me!")
    CAT("\nMy scales are coming off!")WAI(32)CLO()
    ANP("Kanpa1","start_push",0)
    WAI(32)
    ANP("Kanpa1","end_push",0)
    WAI(32)
    ANP("Arowana1","makeSmoke",1)
    ANP("Arowana1","normal",1)
    ANP("Kanpa1","MYB",0)
    WAI(32)
    MS3("Who are you?!")NOD()
    MS3("\nWhy did you take me out of the pool?")NOD()
    WAI(8)CAT("\n.")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")WAI(8)CAT(".")CLR()
    ANP("Arowana1","jump",1)
    ANP("Arowana1","angry",1)
    ANP("Kanpa1","MYB",0)
    CAT("What?!")NOD()CAT("You want to feed me to a cat?")NOD()
    CAT("\nI'm the one and only")
    CAT("\nprecious Arowana here!")NOD()CLR()
    CAT("How dare you--!")NOD()
    CAT("\nI'll kill you!!")NOD()CLO()
    SKP("QuickFishBoss")
    ANP("Kanpa1","MYB",0)
    CMU("CS_Gravity")
    WAI(32)
    CNP("ArowanaBoss","CS_boss_arowana",0,1)
    MNP("ArowanaBoss","Arowana1")
    BSL("ArowanaBoss")
    FLP("InBossFight")
    DNP("Arowana1")
    MOV("Kanpa1")
    DNP("Kanpa1")
    SLR(0)
    SMC()
end

function QuickFishBoss()
    PRI()
    CMU("CS_Gravity")
    CNP("ArowanaBoss","CS_boss_arowana",0,1)
    MNP("ArowanaBoss",18,10,1)
    ANP("ArowanaBoss",0,1)
    BSL("ArowanaBoss")
    FLP("InBossFight")
    MOV(25,10)
    SLR(0)
    SMC()
    FAI(1)
end

function ArowanaBoss()
    PRI()
    FLS("InBossFight")
    CMU("XXXX")
    MS3("\nI lost...")NOD()CLR()CLO()
    ANP("ArowanaBoss","set_player_type")--改成玩家类型防止掉下去
    KEY()
    WAI(80)
    CMU("CS_Fanfale3")
    MSG("\nDefeated Arowana!")WAI(140)NOD()
    FLP("CannotGoOut")
    FLP("DefeatedArowana")
    SKS("QuickFishBoss")
    CMU("XXXX")
    --替换实体
    CNP("ArowanaBoss","GetArowana")
end

function GetArowana()
    PRI()
    GIT("Arowana")ITP("Arowana")SOU("CS_038_get_item")
    ANP("GetArowana","hide")
    DNP("GetArowana")
    CMU("CS_Fanfale1")
    MSG("\nGot the =AROWANA=.")WAI(160)NOD()
    CMU("XXXX")
    FLS("CannotGoOut")
    SetSavePoint()
end

function LoadPos()
    PRI()MNA()CMU("XXXX")
    POS()
    FAI(2)
end

function SetSavePoint()
    CNP("SavePoint","CS_savepoint",0,0)
end
